"""AdvancedTimeSteppingAnalysisForModulationType"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION_TYPE = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads",
    "AdvancedTimeSteppingAnalysisForModulationType",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="AdvancedTimeSteppingAnalysisForModulationType")
    CastSelf = TypeVar(
        "CastSelf",
        bound="AdvancedTimeSteppingAnalysisForModulationType._Cast_AdvancedTimeSteppingAnalysisForModulationType",
    )


__docformat__ = "restructuredtext en"
__all__ = ("AdvancedTimeSteppingAnalysisForModulationType",)


class AdvancedTimeSteppingAnalysisForModulationType(Enum):
    """AdvancedTimeSteppingAnalysisForModulationType

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION_TYPE

    QUASI_HARMONIC_ANALYSIS = 0
    SEPARATION_OF_TIMESCALES_TIME_STEPPING = 1


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


AdvancedTimeSteppingAnalysisForModulationType.__setattr__ = __enum_setattr
AdvancedTimeSteppingAnalysisForModulationType.__delattr__ = __enum_delattr



"""PlanetaryConnectionLoadCase"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.static_loads import _7878

_PLANETARY_CONNECTION_LOAD_CASE = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads",
    "PlanetaryConnectionLoadCase",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2942, _2944, _2946
    from mastapy._private.system_model.analyses_and_results.static_loads import (
        _7732,
        _7772,
    )
    from mastapy._private.system_model.connections_and_sockets import _2547

    Self = TypeVar("Self", bound="PlanetaryConnectionLoadCase")
    CastSelf = TypeVar(
        "CastSelf",
        bound="PlanetaryConnectionLoadCase._Cast_PlanetaryConnectionLoadCase",
    )


__docformat__ = "restructuredtext en"
__all__ = ("PlanetaryConnectionLoadCase",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_PlanetaryConnectionLoadCase:
    """Special nested class for casting PlanetaryConnectionLoadCase to subclasses."""

    __parent__: "PlanetaryConnectionLoadCase"

    @property
    def shaft_to_mountable_component_connection_load_case(
        self: "CastSelf",
    ) -> "_7878.ShaftToMountableComponentConnectionLoadCase":
        return self.__parent__._cast(_7878.ShaftToMountableComponentConnectionLoadCase)

    @property
    def abstract_shaft_to_mountable_component_connection_load_case(
        self: "CastSelf",
    ) -> "_7732.AbstractShaftToMountableComponentConnectionLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7732,
        )

        return self.__parent__._cast(
            _7732.AbstractShaftToMountableComponentConnectionLoadCase
        )

    @property
    def connection_load_case(self: "CastSelf") -> "_7772.ConnectionLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7772,
        )

        return self.__parent__._cast(_7772.ConnectionLoadCase)

    @property
    def connection_analysis(self: "CastSelf") -> "_2942.ConnectionAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2942

        return self.__parent__._cast(_2942.ConnectionAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def planetary_connection_load_case(
        self: "CastSelf",
    ) -> "PlanetaryConnectionLoadCase":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class PlanetaryConnectionLoadCase(_7878.ShaftToMountableComponentConnectionLoadCase):
    """PlanetaryConnectionLoadCase

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _PLANETARY_CONNECTION_LOAD_CASE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def connection_design(self: "Self") -> "_2547.PlanetaryConnection":
        """mastapy.system_model.connections_and_sockets.PlanetaryConnection

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_PlanetaryConnectionLoadCase":
        """Cast to another type.

        Returns:
            _Cast_PlanetaryConnectionLoadCase
        """
        return _Cast_PlanetaryConnectionLoadCase(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6239 import (
        AbstractAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6240 import (
        AbstractShaftCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6241 import (
        AbstractShaftOrHousingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6242 import (
        AbstractShaftToMountableComponentConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6243 import (
        AGMAGleasonConicalGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6244 import (
        AGMAGleasonConicalGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6245 import (
        AGMAGleasonConicalGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6246 import (
        AssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6247 import (
        BearingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6248 import (
        BeltConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6249 import (
        BeltDriveCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6250 import (
        BevelDifferentialGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6251 import (
        BevelDifferentialGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6252 import (
        BevelDifferentialGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6253 import (
        BevelDifferentialPlanetGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6254 import (
        BevelDifferentialSunGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6255 import (
        BevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6256 import (
        BevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6257 import (
        BevelGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6258 import (
        BoltCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6259 import (
        BoltedJointCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6260 import (
        ClutchCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6261 import (
        ClutchConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6262 import (
        ClutchHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6263 import (
        CoaxialConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6264 import (
        ComponentCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6265 import (
        ConceptCouplingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6266 import (
        ConceptCouplingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6267 import (
        ConceptCouplingHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6268 import (
        ConceptGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6269 import (
        ConceptGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6270 import (
        ConceptGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6271 import (
        ConicalGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6272 import (
        ConicalGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6273 import (
        ConicalGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6274 import (
        ConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6275 import (
        ConnectorCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6276 import (
        CouplingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6277 import (
        CouplingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6278 import (
        CouplingHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6279 import (
        CVTBeltConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6280 import (
        CVTCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6281 import (
        CVTPulleyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6282 import (
        CycloidalAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6283 import (
        CycloidalDiscCentralBearingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6284 import (
        CycloidalDiscCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6285 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6286 import (
        CylindricalGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6287 import (
        CylindricalGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6288 import (
        CylindricalGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6289 import (
        CylindricalPlanetGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6290 import (
        DatumCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6291 import (
        ExternalCADModelCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6292 import (
        FaceGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6293 import (
        FaceGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6294 import (
        FaceGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6295 import (
        FEPartCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6296 import (
        FlexiblePinAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6297 import (
        GearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6298 import (
        GearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6299 import (
        GearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6300 import (
        GuideDxfModelCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6301 import (
        HypoidGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6302 import (
        HypoidGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6303 import (
        HypoidGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6304 import (
        InterMountableComponentConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6305 import (
        KlingelnbergCycloPalloidConicalGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6306 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6307 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6308 import (
        KlingelnbergCycloPalloidHypoidGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6309 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6310 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6311 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6312 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6313 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6314 import (
        MassDiscCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6315 import (
        MeasurementComponentCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6316 import (
        MicrophoneArrayCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6317 import (
        MicrophoneCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6318 import (
        MountableComponentCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6319 import (
        OilSealCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6320 import (
        PartCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6321 import (
        PartToPartShearCouplingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6322 import (
        PartToPartShearCouplingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6323 import (
        PartToPartShearCouplingHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6324 import (
        PlanetaryConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6325 import (
        PlanetaryGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6326 import (
        PlanetCarrierCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6327 import (
        PointLoadCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6328 import (
        PowerLoadCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6329 import (
        PulleyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6330 import (
        RingPinsCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6331 import (
        RingPinsToDiscConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6332 import (
        RollingRingAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6333 import (
        RollingRingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6334 import (
        RollingRingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6335 import (
        RootAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6336 import (
        ShaftCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6337 import (
        ShaftHubConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6338 import (
        ShaftToMountableComponentConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6339 import (
        SpecialisedAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6340 import (
        SpiralBevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6341 import (
        SpiralBevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6342 import (
        SpiralBevelGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6343 import (
        SpringDamperCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6344 import (
        SpringDamperConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6345 import (
        SpringDamperHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6346 import (
        StraightBevelDiffGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6347 import (
        StraightBevelDiffGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6348 import (
        StraightBevelDiffGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6349 import (
        StraightBevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6350 import (
        StraightBevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6351 import (
        StraightBevelGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6352 import (
        StraightBevelPlanetGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6353 import (
        StraightBevelSunGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6354 import (
        SynchroniserCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6355 import (
        SynchroniserHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6356 import (
        SynchroniserPartCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6357 import (
        SynchroniserSleeveCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6358 import (
        TorqueConverterCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6359 import (
        TorqueConverterConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6360 import (
        TorqueConverterPumpCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6361 import (
        TorqueConverterTurbineCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6362 import (
        UnbalancedMassCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6363 import (
        VirtualComponentCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6364 import (
        WormGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6365 import (
        WormGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6366 import (
        WormGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6367 import (
        ZerolBevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6368 import (
        ZerolBevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6369 import (
        ZerolBevelGearSetCompoundHarmonicAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6239": [
            "AbstractAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6240": [
            "AbstractShaftCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6241": [
            "AbstractShaftOrHousingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6242": [
            "AbstractShaftToMountableComponentConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6243": [
            "AGMAGleasonConicalGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6244": [
            "AGMAGleasonConicalGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6245": [
            "AGMAGleasonConicalGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6246": [
            "AssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6247": [
            "BearingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6248": [
            "BeltConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6249": [
            "BeltDriveCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6250": [
            "BevelDifferentialGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6251": [
            "BevelDifferentialGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6252": [
            "BevelDifferentialGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6253": [
            "BevelDifferentialPlanetGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6254": [
            "BevelDifferentialSunGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6255": [
            "BevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6256": [
            "BevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6257": [
            "BevelGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6258": [
            "BoltCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6259": [
            "BoltedJointCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6260": [
            "ClutchCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6261": [
            "ClutchConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6262": [
            "ClutchHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6263": [
            "CoaxialConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6264": [
            "ComponentCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6265": [
            "ConceptCouplingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6266": [
            "ConceptCouplingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6267": [
            "ConceptCouplingHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6268": [
            "ConceptGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6269": [
            "ConceptGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6270": [
            "ConceptGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6271": [
            "ConicalGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6272": [
            "ConicalGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6273": [
            "ConicalGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6274": [
            "ConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6275": [
            "ConnectorCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6276": [
            "CouplingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6277": [
            "CouplingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6278": [
            "CouplingHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6279": [
            "CVTBeltConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6280": [
            "CVTCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6281": [
            "CVTPulleyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6282": [
            "CycloidalAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6283": [
            "CycloidalDiscCentralBearingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6284": [
            "CycloidalDiscCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6285": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6286": [
            "CylindricalGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6287": [
            "CylindricalGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6288": [
            "CylindricalGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6289": [
            "CylindricalPlanetGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6290": [
            "DatumCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6291": [
            "ExternalCADModelCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6292": [
            "FaceGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6293": [
            "FaceGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6294": [
            "FaceGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6295": [
            "FEPartCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6296": [
            "FlexiblePinAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6297": [
            "GearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6298": [
            "GearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6299": [
            "GearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6300": [
            "GuideDxfModelCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6301": [
            "HypoidGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6302": [
            "HypoidGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6303": [
            "HypoidGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6304": [
            "InterMountableComponentConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6305": [
            "KlingelnbergCycloPalloidConicalGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6306": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6307": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6308": [
            "KlingelnbergCycloPalloidHypoidGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6309": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6310": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6311": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6312": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6313": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6314": [
            "MassDiscCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6315": [
            "MeasurementComponentCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6316": [
            "MicrophoneArrayCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6317": [
            "MicrophoneCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6318": [
            "MountableComponentCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6319": [
            "OilSealCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6320": [
            "PartCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6321": [
            "PartToPartShearCouplingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6322": [
            "PartToPartShearCouplingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6323": [
            "PartToPartShearCouplingHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6324": [
            "PlanetaryConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6325": [
            "PlanetaryGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6326": [
            "PlanetCarrierCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6327": [
            "PointLoadCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6328": [
            "PowerLoadCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6329": [
            "PulleyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6330": [
            "RingPinsCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6331": [
            "RingPinsToDiscConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6332": [
            "RollingRingAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6333": [
            "RollingRingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6334": [
            "RollingRingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6335": [
            "RootAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6336": [
            "ShaftCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6337": [
            "ShaftHubConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6338": [
            "ShaftToMountableComponentConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6339": [
            "SpecialisedAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6340": [
            "SpiralBevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6341": [
            "SpiralBevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6342": [
            "SpiralBevelGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6343": [
            "SpringDamperCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6344": [
            "SpringDamperConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6345": [
            "SpringDamperHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6346": [
            "StraightBevelDiffGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6347": [
            "StraightBevelDiffGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6348": [
            "StraightBevelDiffGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6349": [
            "StraightBevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6350": [
            "StraightBevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6351": [
            "StraightBevelGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6352": [
            "StraightBevelPlanetGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6353": [
            "StraightBevelSunGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6354": [
            "SynchroniserCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6355": [
            "SynchroniserHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6356": [
            "SynchroniserPartCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6357": [
            "SynchroniserSleeveCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6358": [
            "TorqueConverterCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6359": [
            "TorqueConverterConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6360": [
            "TorqueConverterPumpCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6361": [
            "TorqueConverterTurbineCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6362": [
            "UnbalancedMassCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6363": [
            "VirtualComponentCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6364": [
            "WormGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6365": [
            "WormGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6366": [
            "WormGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6367": [
            "ZerolBevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6368": [
            "ZerolBevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6369": [
            "ZerolBevelGearSetCompoundHarmonicAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundHarmonicAnalysis",
    "AbstractShaftCompoundHarmonicAnalysis",
    "AbstractShaftOrHousingCompoundHarmonicAnalysis",
    "AbstractShaftToMountableComponentConnectionCompoundHarmonicAnalysis",
    "AGMAGleasonConicalGearCompoundHarmonicAnalysis",
    "AGMAGleasonConicalGearMeshCompoundHarmonicAnalysis",
    "AGMAGleasonConicalGearSetCompoundHarmonicAnalysis",
    "AssemblyCompoundHarmonicAnalysis",
    "BearingCompoundHarmonicAnalysis",
    "BeltConnectionCompoundHarmonicAnalysis",
    "BeltDriveCompoundHarmonicAnalysis",
    "BevelDifferentialGearCompoundHarmonicAnalysis",
    "BevelDifferentialGearMeshCompoundHarmonicAnalysis",
    "BevelDifferentialGearSetCompoundHarmonicAnalysis",
    "BevelDifferentialPlanetGearCompoundHarmonicAnalysis",
    "BevelDifferentialSunGearCompoundHarmonicAnalysis",
    "BevelGearCompoundHarmonicAnalysis",
    "BevelGearMeshCompoundHarmonicAnalysis",
    "BevelGearSetCompoundHarmonicAnalysis",
    "BoltCompoundHarmonicAnalysis",
    "BoltedJointCompoundHarmonicAnalysis",
    "ClutchCompoundHarmonicAnalysis",
    "ClutchConnectionCompoundHarmonicAnalysis",
    "ClutchHalfCompoundHarmonicAnalysis",
    "CoaxialConnectionCompoundHarmonicAnalysis",
    "ComponentCompoundHarmonicAnalysis",
    "ConceptCouplingCompoundHarmonicAnalysis",
    "ConceptCouplingConnectionCompoundHarmonicAnalysis",
    "ConceptCouplingHalfCompoundHarmonicAnalysis",
    "ConceptGearCompoundHarmonicAnalysis",
    "ConceptGearMeshCompoundHarmonicAnalysis",
    "ConceptGearSetCompoundHarmonicAnalysis",
    "ConicalGearCompoundHarmonicAnalysis",
    "ConicalGearMeshCompoundHarmonicAnalysis",
    "ConicalGearSetCompoundHarmonicAnalysis",
    "ConnectionCompoundHarmonicAnalysis",
    "ConnectorCompoundHarmonicAnalysis",
    "CouplingCompoundHarmonicAnalysis",
    "CouplingConnectionCompoundHarmonicAnalysis",
    "CouplingHalfCompoundHarmonicAnalysis",
    "CVTBeltConnectionCompoundHarmonicAnalysis",
    "CVTCompoundHarmonicAnalysis",
    "CVTPulleyCompoundHarmonicAnalysis",
    "CycloidalAssemblyCompoundHarmonicAnalysis",
    "CycloidalDiscCentralBearingConnectionCompoundHarmonicAnalysis",
    "CycloidalDiscCompoundHarmonicAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionCompoundHarmonicAnalysis",
    "CylindricalGearCompoundHarmonicAnalysis",
    "CylindricalGearMeshCompoundHarmonicAnalysis",
    "CylindricalGearSetCompoundHarmonicAnalysis",
    "CylindricalPlanetGearCompoundHarmonicAnalysis",
    "DatumCompoundHarmonicAnalysis",
    "ExternalCADModelCompoundHarmonicAnalysis",
    "FaceGearCompoundHarmonicAnalysis",
    "FaceGearMeshCompoundHarmonicAnalysis",
    "FaceGearSetCompoundHarmonicAnalysis",
    "FEPartCompoundHarmonicAnalysis",
    "FlexiblePinAssemblyCompoundHarmonicAnalysis",
    "GearCompoundHarmonicAnalysis",
    "GearMeshCompoundHarmonicAnalysis",
    "GearSetCompoundHarmonicAnalysis",
    "GuideDxfModelCompoundHarmonicAnalysis",
    "HypoidGearCompoundHarmonicAnalysis",
    "HypoidGearMeshCompoundHarmonicAnalysis",
    "HypoidGearSetCompoundHarmonicAnalysis",
    "InterMountableComponentConnectionCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundHarmonicAnalysis",
    "MassDiscCompoundHarmonicAnalysis",
    "MeasurementComponentCompoundHarmonicAnalysis",
    "MicrophoneArrayCompoundHarmonicAnalysis",
    "MicrophoneCompoundHarmonicAnalysis",
    "MountableComponentCompoundHarmonicAnalysis",
    "OilSealCompoundHarmonicAnalysis",
    "PartCompoundHarmonicAnalysis",
    "PartToPartShearCouplingCompoundHarmonicAnalysis",
    "PartToPartShearCouplingConnectionCompoundHarmonicAnalysis",
    "PartToPartShearCouplingHalfCompoundHarmonicAnalysis",
    "PlanetaryConnectionCompoundHarmonicAnalysis",
    "PlanetaryGearSetCompoundHarmonicAnalysis",
    "PlanetCarrierCompoundHarmonicAnalysis",
    "PointLoadCompoundHarmonicAnalysis",
    "PowerLoadCompoundHarmonicAnalysis",
    "PulleyCompoundHarmonicAnalysis",
    "RingPinsCompoundHarmonicAnalysis",
    "RingPinsToDiscConnectionCompoundHarmonicAnalysis",
    "RollingRingAssemblyCompoundHarmonicAnalysis",
    "RollingRingCompoundHarmonicAnalysis",
    "RollingRingConnectionCompoundHarmonicAnalysis",
    "RootAssemblyCompoundHarmonicAnalysis",
    "ShaftCompoundHarmonicAnalysis",
    "ShaftHubConnectionCompoundHarmonicAnalysis",
    "ShaftToMountableComponentConnectionCompoundHarmonicAnalysis",
    "SpecialisedAssemblyCompoundHarmonicAnalysis",
    "SpiralBevelGearCompoundHarmonicAnalysis",
    "SpiralBevelGearMeshCompoundHarmonicAnalysis",
    "SpiralBevelGearSetCompoundHarmonicAnalysis",
    "SpringDamperCompoundHarmonicAnalysis",
    "SpringDamperConnectionCompoundHarmonicAnalysis",
    "SpringDamperHalfCompoundHarmonicAnalysis",
    "StraightBevelDiffGearCompoundHarmonicAnalysis",
    "StraightBevelDiffGearMeshCompoundHarmonicAnalysis",
    "StraightBevelDiffGearSetCompoundHarmonicAnalysis",
    "StraightBevelGearCompoundHarmonicAnalysis",
    "StraightBevelGearMeshCompoundHarmonicAnalysis",
    "StraightBevelGearSetCompoundHarmonicAnalysis",
    "StraightBevelPlanetGearCompoundHarmonicAnalysis",
    "StraightBevelSunGearCompoundHarmonicAnalysis",
    "SynchroniserCompoundHarmonicAnalysis",
    "SynchroniserHalfCompoundHarmonicAnalysis",
    "SynchroniserPartCompoundHarmonicAnalysis",
    "SynchroniserSleeveCompoundHarmonicAnalysis",
    "TorqueConverterCompoundHarmonicAnalysis",
    "TorqueConverterConnectionCompoundHarmonicAnalysis",
    "TorqueConverterPumpCompoundHarmonicAnalysis",
    "TorqueConverterTurbineCompoundHarmonicAnalysis",
    "UnbalancedMassCompoundHarmonicAnalysis",
    "VirtualComponentCompoundHarmonicAnalysis",
    "WormGearCompoundHarmonicAnalysis",
    "WormGearMeshCompoundHarmonicAnalysis",
    "WormGearSetCompoundHarmonicAnalysis",
    "ZerolBevelGearCompoundHarmonicAnalysis",
    "ZerolBevelGearMeshCompoundHarmonicAnalysis",
    "ZerolBevelGearSetCompoundHarmonicAnalysis",
)



"""GBT17855SplineJointRating"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import utility
from mastapy._private.detailed_rigid_connectors.splines.ratings import _1645

_GBT17855_SPLINE_JOINT_RATING = python_net_import(
    "SMT.MastaAPI.DetailedRigidConnectors.Splines.Ratings", "GBT17855SplineJointRating"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.detailed_rigid_connectors.rating import _1649

    Self = TypeVar("Self", bound="GBT17855SplineJointRating")
    CastSelf = TypeVar(
        "CastSelf", bound="GBT17855SplineJointRating._Cast_GBT17855SplineJointRating"
    )


__docformat__ = "restructuredtext en"
__all__ = ("GBT17855SplineJointRating",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_GBT17855SplineJointRating:
    """Special nested class for casting GBT17855SplineJointRating to subclasses."""

    __parent__: "GBT17855SplineJointRating"

    @property
    def spline_joint_rating(self: "CastSelf") -> "_1645.SplineJointRating":
        return self.__parent__._cast(_1645.SplineJointRating)

    @property
    def shaft_hub_connection_rating(
        self: "CastSelf",
    ) -> "_1649.ShaftHubConnectionRating":
        from mastapy._private.detailed_rigid_connectors.rating import _1649

        return self.__parent__._cast(_1649.ShaftHubConnectionRating)

    @property
    def gbt17855_spline_joint_rating(self: "CastSelf") -> "GBT17855SplineJointRating":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class GBT17855SplineJointRating(_1645.SplineJointRating):
    """GBT17855SplineJointRating

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _GBT17855_SPLINE_JOINT_RATING

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def application_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ApplicationFactor")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def backlash_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "BacklashFactor")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def calculated_compressive_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CalculatedCompressiveStress")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def calculated_maximum_tooth_shearing_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "CalculatedMaximumToothShearingStress"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def calculated_root_bending_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CalculatedRootBendingStress")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def distribution_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DistributionFactor")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def equivalent_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "EquivalentStress")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def face_load_distribution_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "FaceLoadDistributionFactor")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def k_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "KFactor")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def name(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Name")

        if temp is None:
            return ""

        return temp

    @property
    @exception_bridge
    def safety_factor_for_compressive_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SafetyFactorForCompressiveStress")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def safety_factor_for_equivalent_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SafetyFactorForEquivalentStress")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def safety_factor_for_root_bending_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SafetyFactorForRootBendingStress")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def safety_factor_for_tooth_shearing_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "SafetyFactorForToothShearingStress"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def safety_factor_for_wearing_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SafetyFactorForWearingStress")

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_GBT17855SplineJointRating":
        """Cast to another type.

        Returns:
            _Cast_GBT17855SplineJointRating
        """
        return _Cast_GBT17855SplineJointRating(self)



"""RingFittingThermalResults"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private import _0
from mastapy._private._internal import conversion, utility

_RING_FITTING_THERMAL_RESULTS = python_net_import(
    "SMT.MastaAPI.Bearings.BearingResults.Rolling.Fitting", "RingFittingThermalResults"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.bearings.bearing_results.rolling.fitting import (
        _2357,
        _2358,
        _2359,
    )

    Self = TypeVar("Self", bound="RingFittingThermalResults")
    CastSelf = TypeVar(
        "CastSelf", bound="RingFittingThermalResults._Cast_RingFittingThermalResults"
    )


__docformat__ = "restructuredtext en"
__all__ = ("RingFittingThermalResults",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_RingFittingThermalResults:
    """Special nested class for casting RingFittingThermalResults to subclasses."""

    __parent__: "RingFittingThermalResults"

    @property
    def inner_ring_fitting_thermal_results(
        self: "CastSelf",
    ) -> "_2357.InnerRingFittingThermalResults":
        from mastapy._private.bearings.bearing_results.rolling.fitting import _2357

        return self.__parent__._cast(_2357.InnerRingFittingThermalResults)

    @property
    def outer_ring_fitting_thermal_results(
        self: "CastSelf",
    ) -> "_2359.OuterRingFittingThermalResults":
        from mastapy._private.bearings.bearing_results.rolling.fitting import _2359

        return self.__parent__._cast(_2359.OuterRingFittingThermalResults)

    @property
    def ring_fitting_thermal_results(self: "CastSelf") -> "RingFittingThermalResults":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class RingFittingThermalResults(_0.APIBase):
    """RingFittingThermalResults

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _RING_FITTING_THERMAL_RESULTS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def change_in_diameter_due_to_interference_and_centrifugal_effects(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ChangeInDiameterDueToInterferenceAndCentrifugalEffects"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def interfacial_clearance_included_in_analysis(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "InterfacialClearanceIncludedInAnalysis"
        )

        if temp is None:
            return False

        return temp

    @property
    @exception_bridge
    def interfacial_normal_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "InterfacialNormalStress")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def maximum_hoop_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MaximumHoopStress")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def name(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Name")

        if temp is None:
            return ""

        return temp

    @property
    @exception_bridge
    def interference_values(self: "Self") -> "List[_2358.InterferenceComponents]":
        """List[mastapy.bearings.bearing_results.rolling.fitting.InterferenceComponents]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "InterferenceValues")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_RingFittingThermalResults":
        """Cast to another type.

        Returns:
            _Cast_RingFittingThermalResults
        """
        return _Cast_RingFittingThermalResults(self)



"""ResultsForMultipleOrders"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private import _0
from mastapy._private._internal import utility

_RESULTS_FOR_MULTIPLE_ORDERS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalyses.ReportablePropertyResults",
    "ResultsForMultipleOrders",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.reportable_property_results import (
        _6226,
        _6227,
    )

    Self = TypeVar("Self", bound="ResultsForMultipleOrders")
    CastSelf = TypeVar(
        "CastSelf", bound="ResultsForMultipleOrders._Cast_ResultsForMultipleOrders"
    )


__docformat__ = "restructuredtext en"
__all__ = ("ResultsForMultipleOrders",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ResultsForMultipleOrders:
    """Special nested class for casting ResultsForMultipleOrders to subclasses."""

    __parent__: "ResultsForMultipleOrders"

    @property
    def results_for_multiple_orders_for_fe_surface(
        self: "CastSelf",
    ) -> "_6226.ResultsForMultipleOrdersForFESurface":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses.reportable_property_results import (
            _6226,
        )

        return self.__parent__._cast(_6226.ResultsForMultipleOrdersForFESurface)

    @property
    def results_for_multiple_orders_for_groups(
        self: "CastSelf",
    ) -> "_6227.ResultsForMultipleOrdersForGroups":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses.reportable_property_results import (
            _6227,
        )

        return self.__parent__._cast(_6227.ResultsForMultipleOrdersForGroups)

    @property
    def results_for_multiple_orders(self: "CastSelf") -> "ResultsForMultipleOrders":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ResultsForMultipleOrders(_0.APIBase):
    """ResultsForMultipleOrders

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _RESULTS_FOR_MULTIPLE_ORDERS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def combined_excitations_harmonics_and_orders(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "CombinedExcitationsHarmonicsAndOrders"
        )

        if temp is None:
            return ""

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_ResultsForMultipleOrders":
        """Cast to another type.

        Returns:
            _Cast_ResultsForMultipleOrders
        """
        return _Cast_ResultsForMultipleOrders(self)



"""BevelGearISOMaterial"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.list_with_selected_item import (
    promote_to_list_with_selected_item,
)
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.sentinels import ListWithSelectedItem_None
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import list_with_selected_item
from mastapy._private.gears.materials import _701

_BEVEL_GEAR_ISO_MATERIAL = python_net_import(
    "SMT.MastaAPI.Gears.Materials", "BevelGearISOMaterial"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.materials import _710
    from mastapy._private.materials import _371, _380
    from mastapy._private.utility.databases import _2063

    Self = TypeVar("Self", bound="BevelGearISOMaterial")
    CastSelf = TypeVar(
        "CastSelf", bound="BevelGearISOMaterial._Cast_BevelGearISOMaterial"
    )


__docformat__ = "restructuredtext en"
__all__ = ("BevelGearISOMaterial",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_BevelGearISOMaterial:
    """Special nested class for casting BevelGearISOMaterial to subclasses."""

    __parent__: "BevelGearISOMaterial"

    @property
    def bevel_gear_material(self: "CastSelf") -> "_701.BevelGearMaterial":
        return self.__parent__._cast(_701.BevelGearMaterial)

    @property
    def gear_material(self: "CastSelf") -> "_710.GearMaterial":
        from mastapy._private.gears.materials import _710

        return self.__parent__._cast(_710.GearMaterial)

    @property
    def material(self: "CastSelf") -> "_371.Material":
        from mastapy._private.materials import _371

        return self.__parent__._cast(_371.Material)

    @property
    def named_database_item(self: "CastSelf") -> "_2063.NamedDatabaseItem":
        from mastapy._private.utility.databases import _2063

        return self.__parent__._cast(_2063.NamedDatabaseItem)

    @property
    def bevel_gear_iso_material(self: "CastSelf") -> "BevelGearISOMaterial":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class BevelGearISOMaterial(_701.BevelGearMaterial):
    """BevelGearISOMaterial

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _BEVEL_GEAR_ISO_MATERIAL

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def allowable_bending_stress(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "AllowableBendingStress")

        if temp is None:
            return 0.0

        return temp

    @allowable_bending_stress.setter
    @exception_bridge
    @enforce_parameter_types
    def allowable_bending_stress(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "AllowableBendingStress",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def allowable_contact_stress(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "AllowableContactStress")

        if temp is None:
            return 0.0

        return temp

    @allowable_contact_stress.setter
    @exception_bridge
    @enforce_parameter_types
    def allowable_contact_stress(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "AllowableContactStress",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def iso_material_type(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_str":
        """ListWithSelectedItem[str]"""
        temp = pythonnet_property_get(self.wrapped, "ISOMaterialType")

        if temp is None:
            return ""

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_str",
        )(temp)

    @iso_material_type.setter
    @exception_bridge
    @enforce_parameter_types
    def iso_material_type(self: "Self", value: "str") -> None:
        generic_type = list_with_selected_item.ListWithSelectedItem_str.implicit_type()
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(self.wrapped, "ISOMaterialType", value)

    @property
    @exception_bridge
    def limited_pitting_allowed(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "LimitedPittingAllowed")

        if temp is None:
            return False

        return temp

    @limited_pitting_allowed.setter
    @exception_bridge
    @enforce_parameter_types
    def limited_pitting_allowed(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "LimitedPittingAllowed",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def long_life_life_factor_bending(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "LongLifeLifeFactorBending")

        if temp is None:
            return 0.0

        return temp

    @long_life_life_factor_bending.setter
    @exception_bridge
    @enforce_parameter_types
    def long_life_life_factor_bending(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "LongLifeLifeFactorBending",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def long_life_life_factor_contact(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "LongLifeLifeFactorContact")

        if temp is None:
            return 0.0

        return temp

    @long_life_life_factor_contact.setter
    @exception_bridge
    @enforce_parameter_types
    def long_life_life_factor_contact(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "LongLifeLifeFactorContact",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def material_has_a_well_defined_yield_point(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "MaterialHasAWellDefinedYieldPoint")

        if temp is None:
            return False

        return temp

    @material_has_a_well_defined_yield_point.setter
    @exception_bridge
    @enforce_parameter_types
    def material_has_a_well_defined_yield_point(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "MaterialHasAWellDefinedYieldPoint",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def n0_bending(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "N0Bending")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def n0_contact(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "N0Contact")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def proof_stress(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "ProofStress")

        if temp is None:
            return 0.0

        return temp

    @proof_stress.setter
    @exception_bridge
    @enforce_parameter_types
    def proof_stress(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "ProofStress", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def quality_grade(self: "Self") -> "_380.QualityGrade":
        """mastapy.materials.QualityGrade"""
        temp = pythonnet_property_get(self.wrapped, "QualityGrade")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(temp, "SMT.MastaAPI.Materials.QualityGrade")

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.materials._380", "QualityGrade"
        )(value)

    @quality_grade.setter
    @exception_bridge
    @enforce_parameter_types
    def quality_grade(self: "Self", value: "_380.QualityGrade") -> None:
        value = conversion.mp_to_pn_enum(value, "SMT.MastaAPI.Materials.QualityGrade")
        pythonnet_property_set(self.wrapped, "QualityGrade", value)

    @property
    @exception_bridge
    def specify_allowable_stress_numbers(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "SpecifyAllowableStressNumbers")

        if temp is None:
            return False

        return temp

    @specify_allowable_stress_numbers.setter
    @exception_bridge
    @enforce_parameter_types
    def specify_allowable_stress_numbers(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "SpecifyAllowableStressNumbers",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def use_iso633652003_material_definitions(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "UseISO633652003MaterialDefinitions"
        )

        if temp is None:
            return False

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_BevelGearISOMaterial":
        """Cast to another type.

        Returns:
            _Cast_BevelGearISOMaterial
        """
        return _Cast_BevelGearISOMaterial(self)



"""BarForPareto"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar, Generic, TypeVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
)

from mastapy._private._internal import utility
from mastapy._private.math_utility.optimisation import _1767

_BAR_FOR_PARETO = python_net_import(
    "SMT.MastaAPI.Gears.GearSetParetoOptimiser", "BarForPareto"
)

if TYPE_CHECKING:
    from typing import Any, Type

    from mastapy._private.gears.analysis import _1363

    Self = TypeVar("Self", bound="BarForPareto")
    CastSelf = TypeVar("CastSelf", bound="BarForPareto._Cast_BarForPareto")

TAnalysis = TypeVar("TAnalysis", bound="_1363.AbstractGearSetAnalysis")
TCandidate = TypeVar("TCandidate")

__docformat__ = "restructuredtext en"
__all__ = ("BarForPareto",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_BarForPareto:
    """Special nested class for casting BarForPareto to subclasses."""

    __parent__: "BarForPareto"

    @property
    def pareto_optimisation_strategy_bars(
        self: "CastSelf",
    ) -> "_1767.ParetoOptimisationStrategyBars":
        return self.__parent__._cast(_1767.ParetoOptimisationStrategyBars)

    @property
    def bar_for_pareto(self: "CastSelf") -> "BarForPareto":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class BarForPareto(
    _1767.ParetoOptimisationStrategyBars, Generic[TAnalysis, TCandidate]
):
    """BarForPareto

    This is a mastapy class.

    Generic Types:
        TAnalysis
        TCandidate
    """

    TYPE: ClassVar["Type"] = _BAR_FOR_PARETO

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @exception_bridge
    def remove_bar(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "RemoveBar")

    @property
    def cast_to(self: "Self") -> "_Cast_BarForPareto":
        """Cast to another type.

        Returns:
            _Cast_BarForPareto
        """
        return _Cast_BarForPareto(self)



"""FindleyCriticalPlaneAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)
from mastapy._private._math.vector_2d import Vector2D

from mastapy._private import _0
from mastapy._private._internal import conversion, utility

_FINDLEY_CRITICAL_PLANE_ANALYSIS = python_net_import(
    "SMT.MastaAPI.Gears.GearTwoDFEAnalysis", "FindleyCriticalPlaneAnalysis"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar("Self", bound="FindleyCriticalPlaneAnalysis")
    CastSelf = TypeVar(
        "CastSelf",
        bound="FindleyCriticalPlaneAnalysis._Cast_FindleyCriticalPlaneAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("FindleyCriticalPlaneAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_FindleyCriticalPlaneAnalysis:
    """Special nested class for casting FindleyCriticalPlaneAnalysis to subclasses."""

    __parent__: "FindleyCriticalPlaneAnalysis"

    @property
    def findley_critical_plane_analysis(
        self: "CastSelf",
    ) -> "FindleyCriticalPlaneAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class FindleyCriticalPlaneAnalysis(_0.APIBase):
    """FindleyCriticalPlaneAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _FINDLEY_CRITICAL_PLANE_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def crack_initiation_risk_factor(self: "Self") -> "List[float]":
        """List[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CrackInitiationRiskFactor")

        if temp is None:
            return None

        value = conversion.to_list_any(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def max_normal_stress(self: "Self") -> "List[float]":
        """List[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MaxNormalStress")

        if temp is None:
            return None

        value = conversion.to_list_any(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def max_shear_amplitude(self: "Self") -> "List[float]":
        """List[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MaxShearAmplitude")

        if temp is None:
            return None

        value = conversion.to_list_any(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def maximum_findley_critical_plane_angle(self: "Self") -> "List[Vector2D]":
        """List[Vector2D]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MaximumFindleyCriticalPlaneAngle")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, Vector2D)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def maximum_findley_critical_plane_stress(self: "Self") -> "List[float]":
        """List[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MaximumFindleyCriticalPlaneStress")

        if temp is None:
            return None

        value = conversion.to_list_any(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_FindleyCriticalPlaneAnalysis":
        """Cast to another type.

        Returns:
            _Cast_FindleyCriticalPlaneAnalysis
        """
        return _Cast_FindleyCriticalPlaneAnalysis(self)



"""PlanetManufactureError"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private import _0
from mastapy._private._internal import utility

_PLANET_MANUFACTURE_ERROR = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads", "PlanetManufactureError"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="PlanetManufactureError")
    CastSelf = TypeVar(
        "CastSelf", bound="PlanetManufactureError._Cast_PlanetManufactureError"
    )


__docformat__ = "restructuredtext en"
__all__ = ("PlanetManufactureError",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_PlanetManufactureError:
    """Special nested class for casting PlanetManufactureError to subclasses."""

    __parent__: "PlanetManufactureError"

    @property
    def planet_manufacture_error(self: "CastSelf") -> "PlanetManufactureError":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class PlanetManufactureError(_0.APIBase):
    """PlanetManufactureError

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _PLANET_MANUFACTURE_ERROR

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def angle_of_error_in_pin_coordinate_system(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "AngleOfErrorInPinCoordinateSystem")

        if temp is None:
            return 0.0

        return temp

    @angle_of_error_in_pin_coordinate_system.setter
    @exception_bridge
    @enforce_parameter_types
    def angle_of_error_in_pin_coordinate_system(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "AngleOfErrorInPinCoordinateSystem",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def angular_error(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "AngularError")

        if temp is None:
            return 0.0

        return temp

    @angular_error.setter
    @exception_bridge
    @enforce_parameter_types
    def angular_error(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "AngularError", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def hole_radial_displacement(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "HoleRadialDisplacement")

        if temp is None:
            return 0.0

        return temp

    @hole_radial_displacement.setter
    @exception_bridge
    @enforce_parameter_types
    def hole_radial_displacement(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "HoleRadialDisplacement",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def name(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Name")

        if temp is None:
            return ""

        return temp

    @property
    @exception_bridge
    def radial_error(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "RadialError")

        if temp is None:
            return 0.0

        return temp

    @radial_error.setter
    @exception_bridge
    @enforce_parameter_types
    def radial_error(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "RadialError", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def radial_error_carrier(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "RadialErrorCarrier")

        if temp is None:
            return 0.0

        return temp

    @radial_error_carrier.setter
    @exception_bridge
    @enforce_parameter_types
    def radial_error_carrier(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "RadialErrorCarrier",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def radial_tilt_error(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "RadialTiltError")

        if temp is None:
            return 0.0

        return temp

    @radial_tilt_error.setter
    @exception_bridge
    @enforce_parameter_types
    def radial_tilt_error(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "RadialTiltError", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def tangential_error(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "TangentialError")

        if temp is None:
            return 0.0

        return temp

    @tangential_error.setter
    @exception_bridge
    @enforce_parameter_types
    def tangential_error(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "TangentialError", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def tangential_tilt_error(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "TangentialTiltError")

        if temp is None:
            return 0.0

        return temp

    @tangential_tilt_error.setter
    @exception_bridge
    @enforce_parameter_types
    def tangential_tilt_error(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "TangentialTiltError",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def x_error(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "XError")

        if temp is None:
            return 0.0

        return temp

    @x_error.setter
    @exception_bridge
    @enforce_parameter_types
    def x_error(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "XError", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def x_tilt_error(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "XTiltError")

        if temp is None:
            return 0.0

        return temp

    @x_tilt_error.setter
    @exception_bridge
    @enforce_parameter_types
    def x_tilt_error(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "XTiltError", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def y_error(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "YError")

        if temp is None:
            return 0.0

        return temp

    @y_error.setter
    @exception_bridge
    @enforce_parameter_types
    def y_error(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "YError", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def y_tilt_error(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "YTiltError")

        if temp is None:
            return 0.0

        return temp

    @y_tilt_error.setter
    @exception_bridge
    @enforce_parameter_types
    def y_tilt_error(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "YTiltError", float(value) if value is not None else 0.0
        )

    @property
    def cast_to(self: "Self") -> "_Cast_PlanetManufactureError":
        """Cast to another type.

        Returns:
            _Cast_PlanetManufactureError
        """
        return _Cast_PlanetManufactureError(self)



"""VirtualSimulationCalculator"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.gears.manufacturing.cylindrical.cutter_simulation import _857

_VIRTUAL_SIMULATION_CALCULATOR = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.CutterSimulation",
    "VirtualSimulationCalculator",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar("Self", bound="VirtualSimulationCalculator")
    CastSelf = TypeVar(
        "CastSelf",
        bound="VirtualSimulationCalculator._Cast_VirtualSimulationCalculator",
    )


__docformat__ = "restructuredtext en"
__all__ = ("VirtualSimulationCalculator",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_VirtualSimulationCalculator:
    """Special nested class for casting VirtualSimulationCalculator to subclasses."""

    __parent__: "VirtualSimulationCalculator"

    @property
    def cutter_simulation_calc(self: "CastSelf") -> "_857.CutterSimulationCalc":
        return self.__parent__._cast(_857.CutterSimulationCalc)

    @property
    def virtual_simulation_calculator(
        self: "CastSelf",
    ) -> "VirtualSimulationCalculator":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class VirtualSimulationCalculator(_857.CutterSimulationCalc):
    """VirtualSimulationCalculator

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _VIRTUAL_SIMULATION_CALCULATOR

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def bending_moment_arm_for_iso_rating_worst(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "BendingMomentArmForISORatingWorst")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def form_factor_for_iso_rating_worst(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "FormFactorForISORatingWorst")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def notch_depth(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "NotchDepth")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def radius_of_critical_point_for_iso_rating_worst(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "RadiusOfCriticalPointForISORatingWorst"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def root_fillet_radius_iso(self: "Self") -> "List[float]":
        """List[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RootFilletRadiusISO")

        if temp is None:
            return None

        value = conversion.to_list_any(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def root_fillet_radius_for_agma_rating(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RootFilletRadiusForAGMARating")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def root_fillet_radius_for_iso_rating(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RootFilletRadiusForISORating")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def root_fillet_radius_for_iso_rating_worst(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RootFilletRadiusForISORatingWorst")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stress_correction_form_factor_worst(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StressCorrectionFormFactorWorst")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stress_correction_factor_for_iso_rating_worst(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "StressCorrectionFactorForISORatingWorst"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def tooth_root_chord_for_iso_rating(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ToothRootChordForISORating")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def tooth_root_chord_for_iso_rating_worst(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ToothRootChordForISORatingWorst")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def rough_cutter_simulation(self: "Self") -> "VirtualSimulationCalculator":
        """mastapy.gears.manufacturing.cylindrical.cutter_simulation.VirtualSimulationCalculator

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RoughCutterSimulation")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_VirtualSimulationCalculator":
        """Cast to another type.

        Returns:
            _Cast_VirtualSimulationCalculator
        """
        return _Cast_VirtualSimulationCalculator(self)



"""AbstractGearSetRating"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.gears.analysis import _1363

_ABSTRACT_GEAR_SET_RATING = python_net_import(
    "SMT.MastaAPI.Gears.Rating", "AbstractGearSetRating"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.gears import _435
    from mastapy._private.gears.rating import _465, _466, _475, _476
    from mastapy._private.gears.rating.agma_gleason_conical import _680
    from mastapy._private.gears.rating.bevel import _669
    from mastapy._private.gears.rating.concept import _665, _666
    from mastapy._private.gears.rating.conical import _654, _655
    from mastapy._private.gears.rating.cylindrical import _576, _577, _593
    from mastapy._private.gears.rating.face import _562, _563
    from mastapy._private.gears.rating.hypoid import _553
    from mastapy._private.gears.rating.klingelnberg_conical import _526
    from mastapy._private.gears.rating.klingelnberg_hypoid import _523
    from mastapy._private.gears.rating.klingelnberg_spiral_bevel import _520
    from mastapy._private.gears.rating.spiral_bevel import _517
    from mastapy._private.gears.rating.straight_bevel import _510
    from mastapy._private.gears.rating.straight_bevel_diff import _513
    from mastapy._private.gears.rating.worm import _488, _489
    from mastapy._private.gears.rating.zerol_bevel import _484

    Self = TypeVar("Self", bound="AbstractGearSetRating")
    CastSelf = TypeVar(
        "CastSelf", bound="AbstractGearSetRating._Cast_AbstractGearSetRating"
    )


__docformat__ = "restructuredtext en"
__all__ = ("AbstractGearSetRating",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_AbstractGearSetRating:
    """Special nested class for casting AbstractGearSetRating to subclasses."""

    __parent__: "AbstractGearSetRating"

    @property
    def abstract_gear_set_analysis(self: "CastSelf") -> "_1363.AbstractGearSetAnalysis":
        return self.__parent__._cast(_1363.AbstractGearSetAnalysis)

    @property
    def gear_set_duty_cycle_rating(self: "CastSelf") -> "_475.GearSetDutyCycleRating":
        from mastapy._private.gears.rating import _475

        return self.__parent__._cast(_475.GearSetDutyCycleRating)

    @property
    def gear_set_rating(self: "CastSelf") -> "_476.GearSetRating":
        from mastapy._private.gears.rating import _476

        return self.__parent__._cast(_476.GearSetRating)

    @property
    def zerol_bevel_gear_set_rating(self: "CastSelf") -> "_484.ZerolBevelGearSetRating":
        from mastapy._private.gears.rating.zerol_bevel import _484

        return self.__parent__._cast(_484.ZerolBevelGearSetRating)

    @property
    def worm_gear_set_duty_cycle_rating(
        self: "CastSelf",
    ) -> "_488.WormGearSetDutyCycleRating":
        from mastapy._private.gears.rating.worm import _488

        return self.__parent__._cast(_488.WormGearSetDutyCycleRating)

    @property
    def worm_gear_set_rating(self: "CastSelf") -> "_489.WormGearSetRating":
        from mastapy._private.gears.rating.worm import _489

        return self.__parent__._cast(_489.WormGearSetRating)

    @property
    def straight_bevel_gear_set_rating(
        self: "CastSelf",
    ) -> "_510.StraightBevelGearSetRating":
        from mastapy._private.gears.rating.straight_bevel import _510

        return self.__parent__._cast(_510.StraightBevelGearSetRating)

    @property
    def straight_bevel_diff_gear_set_rating(
        self: "CastSelf",
    ) -> "_513.StraightBevelDiffGearSetRating":
        from mastapy._private.gears.rating.straight_bevel_diff import _513

        return self.__parent__._cast(_513.StraightBevelDiffGearSetRating)

    @property
    def spiral_bevel_gear_set_rating(
        self: "CastSelf",
    ) -> "_517.SpiralBevelGearSetRating":
        from mastapy._private.gears.rating.spiral_bevel import _517

        return self.__parent__._cast(_517.SpiralBevelGearSetRating)

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_set_rating(
        self: "CastSelf",
    ) -> "_520.KlingelnbergCycloPalloidSpiralBevelGearSetRating":
        from mastapy._private.gears.rating.klingelnberg_spiral_bevel import _520

        return self.__parent__._cast(
            _520.KlingelnbergCycloPalloidSpiralBevelGearSetRating
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_set_rating(
        self: "CastSelf",
    ) -> "_523.KlingelnbergCycloPalloidHypoidGearSetRating":
        from mastapy._private.gears.rating.klingelnberg_hypoid import _523

        return self.__parent__._cast(_523.KlingelnbergCycloPalloidHypoidGearSetRating)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_set_rating(
        self: "CastSelf",
    ) -> "_526.KlingelnbergCycloPalloidConicalGearSetRating":
        from mastapy._private.gears.rating.klingelnberg_conical import _526

        return self.__parent__._cast(_526.KlingelnbergCycloPalloidConicalGearSetRating)

    @property
    def hypoid_gear_set_rating(self: "CastSelf") -> "_553.HypoidGearSetRating":
        from mastapy._private.gears.rating.hypoid import _553

        return self.__parent__._cast(_553.HypoidGearSetRating)

    @property
    def face_gear_set_duty_cycle_rating(
        self: "CastSelf",
    ) -> "_562.FaceGearSetDutyCycleRating":
        from mastapy._private.gears.rating.face import _562

        return self.__parent__._cast(_562.FaceGearSetDutyCycleRating)

    @property
    def face_gear_set_rating(self: "CastSelf") -> "_563.FaceGearSetRating":
        from mastapy._private.gears.rating.face import _563

        return self.__parent__._cast(_563.FaceGearSetRating)

    @property
    def cylindrical_gear_set_duty_cycle_rating(
        self: "CastSelf",
    ) -> "_576.CylindricalGearSetDutyCycleRating":
        from mastapy._private.gears.rating.cylindrical import _576

        return self.__parent__._cast(_576.CylindricalGearSetDutyCycleRating)

    @property
    def cylindrical_gear_set_rating(
        self: "CastSelf",
    ) -> "_577.CylindricalGearSetRating":
        from mastapy._private.gears.rating.cylindrical import _577

        return self.__parent__._cast(_577.CylindricalGearSetRating)

    @property
    def reduced_cylindrical_gear_set_duty_cycle_rating(
        self: "CastSelf",
    ) -> "_593.ReducedCylindricalGearSetDutyCycleRating":
        from mastapy._private.gears.rating.cylindrical import _593

        return self.__parent__._cast(_593.ReducedCylindricalGearSetDutyCycleRating)

    @property
    def conical_gear_set_duty_cycle_rating(
        self: "CastSelf",
    ) -> "_654.ConicalGearSetDutyCycleRating":
        from mastapy._private.gears.rating.conical import _654

        return self.__parent__._cast(_654.ConicalGearSetDutyCycleRating)

    @property
    def conical_gear_set_rating(self: "CastSelf") -> "_655.ConicalGearSetRating":
        from mastapy._private.gears.rating.conical import _655

        return self.__parent__._cast(_655.ConicalGearSetRating)

    @property
    def concept_gear_set_duty_cycle_rating(
        self: "CastSelf",
    ) -> "_665.ConceptGearSetDutyCycleRating":
        from mastapy._private.gears.rating.concept import _665

        return self.__parent__._cast(_665.ConceptGearSetDutyCycleRating)

    @property
    def concept_gear_set_rating(self: "CastSelf") -> "_666.ConceptGearSetRating":
        from mastapy._private.gears.rating.concept import _666

        return self.__parent__._cast(_666.ConceptGearSetRating)

    @property
    def bevel_gear_set_rating(self: "CastSelf") -> "_669.BevelGearSetRating":
        from mastapy._private.gears.rating.bevel import _669

        return self.__parent__._cast(_669.BevelGearSetRating)

    @property
    def agma_gleason_conical_gear_set_rating(
        self: "CastSelf",
    ) -> "_680.AGMAGleasonConicalGearSetRating":
        from mastapy._private.gears.rating.agma_gleason_conical import _680

        return self.__parent__._cast(_680.AGMAGleasonConicalGearSetRating)

    @property
    def abstract_gear_set_rating(self: "CastSelf") -> "AbstractGearSetRating":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class AbstractGearSetRating(_1363.AbstractGearSetAnalysis):
    """AbstractGearSetRating

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ABSTRACT_GEAR_SET_RATING

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def bending_safety_factor_for_fatigue(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "BendingSafetyFactorForFatigue")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def bending_safety_factor_for_static(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "BendingSafetyFactorForStatic")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def contact_safety_factor_for_fatigue(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ContactSafetyFactorForFatigue")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def contact_safety_factor_for_static(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ContactSafetyFactorForStatic")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def normalised_bending_safety_factor_for_fatigue(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "NormalisedBendingSafetyFactorForFatigue"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def normalised_bending_safety_factor_for_static(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "NormalisedBendingSafetyFactorForStatic"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def normalised_contact_safety_factor_for_fatigue(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "NormalisedContactSafetyFactorForFatigue"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def normalised_contact_safety_factor_for_static(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "NormalisedContactSafetyFactorForStatic"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def normalised_safety_factor_for_fatigue(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "NormalisedSafetyFactorForFatigue")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def normalised_safety_factor_for_fatigue_and_static(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "NormalisedSafetyFactorForFatigueAndStatic"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def normalised_safety_factor_for_static(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "NormalisedSafetyFactorForStatic")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def total_gear_reliability(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TotalGearReliability")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def transmission_properties_gears(self: "Self") -> "_435.GearSetDesignGroup":
        """mastapy.gears.GearSetDesignGroup

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TransmissionPropertiesGears")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def gear_mesh_ratings(self: "Self") -> "List[_465.AbstractGearMeshRating]":
        """List[mastapy.gears.rating.AbstractGearMeshRating]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearMeshRatings")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def gear_ratings(self: "Self") -> "List[_466.AbstractGearRating]":
        """List[mastapy.gears.rating.AbstractGearRating]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearRatings")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_AbstractGearSetRating":
        """Cast to another type.

        Returns:
            _Cast_AbstractGearSetRating
        """
        return _Cast_AbstractGearSetRating(self)



"""Implementations of 'ListWithSelectedItem' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from typing import TYPE_CHECKING

from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, conversion, mixins
from mastapy._private.utility import _1826

_ARRAY = python_net_import("System", "Array")
_LIST_WITH_SELECTED_ITEM = python_net_import(
    "SMT.MastaAPI.Utility.Property", "ListWithSelectedItem"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar("Self", bound="ListWithSelectedItem_SystemDirectory")


__docformat__ = "restructuredtext en"
__all__ = ("ListWithSelectedItem_SystemDirectory",)


class ListWithSelectedItem_SystemDirectory(
    _1826.SystemDirectory, mixins.ListWithSelectedItemMixin
):
    """ListWithSelectedItem_SystemDirectory

    A specific implementation of 'ListWithSelectedItem' for 'SystemDirectory' types.
    """

    __qualname__ = "SystemDirectory"

    def __init__(self: "Self", instance_to_wrap: "Any") -> None:
        super().__init__(instance_to_wrap.SelectedValue)
        object.__setattr__(self, "enclosing", instance_to_wrap)

    @classmethod
    def wrapper_type(cls: "Type[ListWithSelectedItem_SystemDirectory]") -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _LIST_WITH_SELECTED_ITEM

    @classmethod
    def implicit_type(cls: "Type[ListWithSelectedItem_SystemDirectory]") -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _1826.SystemDirectory.TYPE

    @property
    @exception_bridge
    def selected_value(self: "Self") -> "_1826.SystemDirectory":
        """mastapy.utility.SystemDirectory

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.enclosing, "SelectedValue")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def available_values(self: "Self") -> "List[_1826.SystemDirectory]":
        """List[mastapy.utility.SystemDirectory]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.enclosing, "AvailableValues")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def invalid_properties(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.enclosing, "InvalidProperties")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def read_only_properties(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.enclosing, "ReadOnlyProperties")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def all_properties_are_read_only(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.enclosing, "AllPropertiesAreReadOnly")

        if temp is None:
            return False

        return temp

    @property
    @exception_bridge
    def all_properties_are_invalid(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.enclosing, "AllPropertiesAreInvalid")

        if temp is None:
            return False

        return temp



"""Rotor"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_get_with_method,
    pythonnet_property_set,
    pythonnet_property_set_with_method,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private import _0
from mastapy._private._internal import (
    constructor,
    conversion,
    overridable_enum_runtime,
    utility,
)
from mastapy._private._internal.implicit import overridable
from mastapy._private.electric_machines import _1411

_DATABASE_WITH_SELECTED_ITEM = python_net_import(
    "SMT.MastaAPI.UtilityGUI.Databases", "DatabaseWithSelectedItem"
)
_ROTOR = python_net_import("SMT.MastaAPI.ElectricMachines", "Rotor")

if TYPE_CHECKING:
    from typing import Any, List, Tuple, Type, TypeVar, Union

    from mastapy._private._internal.typing import PathLike

    from mastapy._private.electric_machines import (
        _1399,
        _1402,
        _1426,
        _1436,
        _1452,
        _1459,
        _1468,
        _1487,
    )

    Self = TypeVar("Self", bound="Rotor")
    CastSelf = TypeVar("CastSelf", bound="Rotor._Cast_Rotor")


__docformat__ = "restructuredtext en"
__all__ = ("Rotor",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Rotor:
    """Special nested class for casting Rotor to subclasses."""

    __parent__: "Rotor"

    @property
    def cad_rotor(self: "CastSelf") -> "_1399.CADRotor":
        from mastapy._private.electric_machines import _1399

        return self.__parent__._cast(_1399.CADRotor)

    @property
    def cad_wound_field_synchronous_rotor(
        self: "CastSelf",
    ) -> "_1402.CADWoundFieldSynchronousRotor":
        from mastapy._private.electric_machines import _1402

        return self.__parent__._cast(_1402.CADWoundFieldSynchronousRotor)

    @property
    def interior_permanent_magnet_and_synchronous_reluctance_rotor(
        self: "CastSelf",
    ) -> "_1436.InteriorPermanentMagnetAndSynchronousReluctanceRotor":
        from mastapy._private.electric_machines import _1436

        return self.__parent__._cast(
            _1436.InteriorPermanentMagnetAndSynchronousReluctanceRotor
        )

    @property
    def permanent_magnet_rotor(self: "CastSelf") -> "_1452.PermanentMagnetRotor":
        from mastapy._private.electric_machines import _1452

        return self.__parent__._cast(_1452.PermanentMagnetRotor)

    @property
    def surface_permanent_magnet_rotor(
        self: "CastSelf",
    ) -> "_1468.SurfacePermanentMagnetRotor":
        from mastapy._private.electric_machines import _1468

        return self.__parent__._cast(_1468.SurfacePermanentMagnetRotor)

    @property
    def wound_field_synchronous_rotor(
        self: "CastSelf",
    ) -> "_1487.WoundFieldSynchronousRotor":
        from mastapy._private.electric_machines import _1487

        return self.__parent__._cast(_1487.WoundFieldSynchronousRotor)

    @property
    def rotor(self: "CastSelf") -> "Rotor":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class Rotor(_0.APIBase):
    """Rotor

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ROTOR

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def bore(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "Bore")

        if temp is None:
            return 0.0

        return temp

    @bore.setter
    @exception_bridge
    @enforce_parameter_types
    def bore(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "Bore", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def d_axis_angle(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DAxisAngle")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def d_axis_and_q_axis_convention(
        self: "Self",
    ) -> "overridable.Overridable_DQAxisConvention":
        """Overridable[mastapy.electric_machines.DQAxisConvention]"""
        temp = pythonnet_property_get(self.wrapped, "DAxisAndQAxisConvention")

        if temp is None:
            return None

        value = overridable.Overridable_DQAxisConvention.wrapped_type()
        return overridable_enum_runtime.create(temp, value)

    @d_axis_and_q_axis_convention.setter
    @exception_bridge
    @enforce_parameter_types
    def d_axis_and_q_axis_convention(
        self: "Self",
        value: "Union[_1411.DQAxisConvention, Tuple[_1411.DQAxisConvention, bool]]",
    ) -> None:
        wrapper_type = overridable.Overridable_DQAxisConvention.wrapper_type()
        enclosed_type = overridable.Overridable_DQAxisConvention.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](
            value if value is not None else None, is_overridden
        )
        pythonnet_property_set(self.wrapped, "DAxisAndQAxisConvention", value)

    @property
    @exception_bridge
    def initial_angle(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "InitialAngle")

        if temp is None:
            return 0.0

        return temp

    @initial_angle.setter
    @exception_bridge
    @enforce_parameter_types
    def initial_angle(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "InitialAngle", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def is_skewed(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "IsSkewed")

        if temp is None:
            return False

        return temp

    @is_skewed.setter
    @exception_bridge
    @enforce_parameter_types
    def is_skewed(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped, "IsSkewed", bool(value) if value is not None else False
        )

    @property
    @exception_bridge
    def kair(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Kair")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def magnet_flux_barrier_length(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "MagnetFluxBarrierLength")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @magnet_flux_barrier_length.setter
    @exception_bridge
    @enforce_parameter_types
    def magnet_flux_barrier_length(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "MagnetFluxBarrierLength", value)

    @property
    @exception_bridge
    def number_of_magnet_segments_in_axial_direction(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(
            self.wrapped, "NumberOfMagnetSegmentsInAxialDirection"
        )

        if temp is None:
            return 0

        return temp

    @number_of_magnet_segments_in_axial_direction.setter
    @exception_bridge
    @enforce_parameter_types
    def number_of_magnet_segments_in_axial_direction(
        self: "Self", value: "int"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "NumberOfMagnetSegmentsInAxialDirection",
            int(value) if value is not None else 0,
        )

    @property
    @exception_bridge
    def number_of_poles(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(self.wrapped, "NumberOfPoles")

        if temp is None:
            return 0

        return temp

    @number_of_poles.setter
    @exception_bridge
    @enforce_parameter_types
    def number_of_poles(self: "Self", value: "int") -> None:
        pythonnet_property_set(
            self.wrapped, "NumberOfPoles", int(value) if value is not None else 0
        )

    @property
    @exception_bridge
    def number_of_slices(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(self.wrapped, "NumberOfSlices")

        if temp is None:
            return 0

        return temp

    @number_of_slices.setter
    @exception_bridge
    @enforce_parameter_types
    def number_of_slices(self: "Self", value: "int") -> None:
        pythonnet_property_set(
            self.wrapped, "NumberOfSlices", int(value) if value is not None else 0
        )

    @property
    @exception_bridge
    def outer_diameter(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "OuterDiameter")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def outer_radius(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "OuterRadius")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def polar_inertia(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PolarInertia")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def rotor_length(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "RotorLength")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @rotor_length.setter
    @exception_bridge
    @enforce_parameter_types
    def rotor_length(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "RotorLength", value)

    @property
    @exception_bridge
    def rotor_material_database(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get_with_method(
            self.wrapped, "RotorMaterialDatabase", "SelectedItemName"
        )

        if temp is None:
            return ""

        return temp

    @rotor_material_database.setter
    @exception_bridge
    @enforce_parameter_types
    def rotor_material_database(self: "Self", value: "str") -> None:
        pythonnet_property_set_with_method(
            self.wrapped,
            "RotorMaterialDatabase",
            "SetSelectedItem",
            str(value) if value is not None else "",
        )

    @property
    @exception_bridge
    def use_same_material_as_stator(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "UseSameMaterialAsStator")

        if temp is None:
            return False

        return temp

    @use_same_material_as_stator.setter
    @exception_bridge
    @enforce_parameter_types
    def use_same_material_as_stator(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "UseSameMaterialAsStator",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def field_winding_specification(
        self: "Self",
    ) -> "_1426.FieldWindingSpecificationBase":
        """mastapy.electric_machines.FieldWindingSpecificationBase

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "FieldWindingSpecification")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def skew_slices(self: "Self") -> "List[_1459.RotorSkewSlice]":
        """List[mastapy.electric_machines.RotorSkewSlice]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SkewSlices")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ReportNames")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @exception_bridge
    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputDefaultReportTo", file_path)

    @exception_bridge
    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetDefaultReportWithEncodedImages"
        )
        return method_result

    @exception_bridge
    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputActiveReportTo", file_path)

    @exception_bridge
    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputActiveReportAsTextTo", file_path)

    @exception_bridge
    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetActiveReportWithEncodedImages"
        )
        return method_result

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportTo",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsMastaReport",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsTextTo",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = pythonnet_method_call(
            self.wrapped,
            "GetNamedReportWithEncodedImages",
            report_name if report_name else "",
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_Rotor":
        """Cast to another type.

        Returns:
            _Cast_Rotor
        """
        return _Cast_Rotor(self)
